@@ -18,7 +18,7 @@ class AllContactsListChannel(
 	"""
 	The group of contacts for whom you receive presence
 
-	@bug On Maemo 5 this isn't even being created, I think
+	@bug On Maemo 5 this is being ignored
 	"""
 
 	def __init__(self, connection, manager, props, listHandle):
