@@ -10,6 +10,7 @@ try:
 except ImportError:
 	import pickle
 
+import constants
 import util.coroutines as coroutines
 import util.misc as util_misc
 
@@ -33,14 +34,23 @@ class Conversations(object):
 		assert not self._conversations
 		try:
 			with open(path, "rb") as f:
-				self._conversations = pickle.load(f)
+				fileVersion, fileBuild, convs = pickle.load(f)
 		except (pickle.PickleError, IOError):
 			_moduleLogger.exception("While loading for %s" % self._name)
+			return
+
+		if fileVersion == constants.__version__ and fileBuild == constants.__build__:
+			self._conversations = convs
+		else:
+			_moduleLogger.debug(
+				"%s Skipping cache due to version mismatch (%s-%s)" % (self._name, fileVersion, fileBuild)
+			)
 
 	def save(self, path):
 		try:
+			dataToDump = (constants.__version__, constants.__build__, self._conversations)
 			with open(path, "wb") as f:
-				pickle.dump(self._conversations, f, pickle.HIGHEST_PROTOCOL)
+				pickle.dump(dataToDump, f, pickle.HIGHEST_PROTOCOL)
 		except (pickle.PickleError, IOError):
 			_moduleLogger.exception("While saving for %s" % self._name)
 
@@ -66,7 +76,7 @@ class Conversations(object):
 				isConversationUpdated = True
 			except RuntimeError, e:
 				if False:
-					_moduleLogger.info("%s Skipping conversation for %r because '%s'" % (self._name, key, e))
+					_moduleLogger.debug("%s Skipping conversation for %r because '%s'" % (self._name, key, e))
 				isConversationUpdated = False
 
 			if isConversationUpdated:
@@ -104,6 +114,11 @@ class MergedConversations(object):
 			self._remove_repeats(similarConversation, newConversation)
 		self._conversations.append(newConversation)
 
+	def to_dict(self):
+		selfDict = {}
+		selfDict["conversations"] = [conv.to_dict() for conv in self._conversations]
+		return selfDict
+
 	@property
 	def conversations(self):
 		return self._conversations
@@ -141,8 +156,7 @@ class MergedConversations(object):
 			for newMessage in newConversationMessages
 			if newMessage not in relatedConversation.messages
 		]
-		_moduleLogger.debug("%s Found %d new messages in conversation %s (%d/%d)" % (
-			self._name,
+		_moduleLogger.debug("Found %d new messages in conversation %s (%d/%d)" % (
 			len(newConversationMessages) - len(newConversation.messages),
 			newConversation.id,
 			len(newConversation.messages),
